@@ -1,16 +1,17 @@
 use clap::ArgMatches;
+use miette::Result;
 use mit_commit_message_lints::{external, lints::read_from_toml_or_else_vcs};
 
-use crate::{current_dir, errors::GitMitConfigError, get_vcs};
+use crate::{current_dir, get_vcs};
 
-pub(crate) fn run_on_match(matches: &ArgMatches) -> Option<Result<(), GitMitConfigError>> {
+pub(crate) fn run_on_match(matches: &ArgMatches) -> Option<Result<()>> {
     matches
         .subcommand_matches("lint")
         .filter(|subcommand| subcommand.subcommand_matches("enabled").is_some())
         .map(|_| run(matches))
 }
 
-fn run(matches: &ArgMatches) -> Result<(), GitMitConfigError> {
+fn run(matches: &ArgMatches) -> Result<()> {
     let is_local = Some("local") == matches.value_of("scope");
     let current_dir = current_dir()?;
     let mut vcs = get_vcs(is_local, &current_dir)?;
