@@ -4,17 +4,24 @@ use thiserror::Error;
 #[derive(Error, Debug, Diagnostic)]
 pub enum GitMitConfigError {
     #[error("lint name not given")]
-    #[diagnostic()]
+    #[diagnostic(
+        url(docsrs),
+        code(git_mit_config::errors::git_mit_config_error::lint_name_not_given)
+    )]
     LintNameNotGiven,
     #[error("author file not set")]
-    #[diagnostic()]
+    #[diagnostic(
+        url(docsrs),
+        code(git_mit_config::errors::git_mit_config_error::author_file_not_set)
+    )]
     AuthorFileNotSet,
 }
 
 #[derive(Error, Debug, Diagnostic)]
 #[error("unrecognised subcommand")]
 #[diagnostic(
-    code(git_mit::config::author::load),
+    code(git_mit_config::errors::unrecognised_lint_command),
+    url(docsrs),
     help("try `git mit-config --help`")
 )]
 pub struct UnrecognisedLintCommand {}
@@ -23,7 +30,8 @@ pub struct UnrecognisedLintCommand {}
 pub enum LibGit2 {
     #[error("unable to discover git repository")]
     #[diagnostic(
-        code(git_mit::config::author::load),
+        code(git_mit_config::errors::lib_git2::discover_git_repository),
+        url(docsrs),
         help("is the directory a git repository")
     )]
     DiscoverGitRepository {
@@ -33,7 +41,8 @@ pub enum LibGit2 {
 
     #[error("unable to read the configuration from the git repository")]
     #[diagnostic(
-        code(git_mit::config::author::load),
+        code(git_mit_config::errors::lib_git2::read_config_from_git_repository),
+        url(docsrs),
         help("is there a problem with the git repository config?")
     )]
     ReadConfigFromGitRepository {
@@ -42,7 +51,8 @@ pub enum LibGit2 {
     },
     #[error("unable to read git's configuration")]
     #[diagnostic(
-        code(git_mit::config::author::load),
+        code(git_mit_config::errors::lib_git2::read_user_config_from_git),
+        url(docsrs),
         help("is there a problem with the git user config?")
     )]
     ReadUserConfigFromGit {
